.. NNgen documentation master file, created by
   sphinx-quickstart on Tue Jun 11 10:23:49 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NNgen's documentation!
=================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   operator
   pynq

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
